==> qtjambi-network-debuginfo-macos-6.5.7.jar: sources/QtJambiNetwork/QDnsLookup_shell.h <==
#ifndef QDNSLOOKUP_SHELL_H
#define QDNSLOOKUP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dnslookup)

class QDnsLookup_shell : public QDnsLookup, public QtJambiShellInterface
{
public:
    QDnsLookup_shell(QDnsLookup::Type type0, const QString& name1, QObject* parent2 = nullptr);
    QDnsLookup_shell(QObject* parent0 = nullptr);
    ~QDnsLookup_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QDnsLookup_mshell;
    friend class QDnsLookup_oshell;
};


class QDnsLookup_mshell : public QDnsLookup_shell
{
public:
    using QDnsLookup_shell::QDnsLookup_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QDnsLookup_oshell : public QDnsLookup_mshell
{
public:
    using QDnsLookup_mshell::QDnsLookup_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDnsLookup_access : public QDnsLookup
{
};

#endif // QT_CONFIG(dnslookup)
#endif // QDNSLOOKUP_SHELL_H

==> qtjambi-network-debuginfo-macos-6.6.0.jar: sources/QtJambiNetwork/QDnsLookup_shell.h <==
#ifndef QDNSLOOKUP_SHELL_H
#define QDNSLOOKUP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qhostaddress.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dnslookup)

class QDnsLookup_shell : public QDnsLookup, public QtJambiShellInterface
{
public:
    QDnsLookup_shell(QDnsLookup::Type type0, const QString& name1, QObject* parent2 = nullptr);
    QDnsLookup_shell(QDnsLookup::Type type0, const QString& name1, const QHostAddress& nameserver2, quint16 port3, QObject* parent4 = nullptr);
    QDnsLookup_shell(QObject* parent0 = nullptr);
    ~QDnsLookup_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDnsLookup_access : public QDnsLookup
{
};

#endif // QT_CONFIG(dnslookup)
#endif // QDNSLOOKUP_SHELL_H
